#ifndef SCHEDULEDLIST_H
#define SCHEDULEDLIST_H

#include <QWidget>
#include <QModelIndex>

class ScheduledList : public QWidget
{
        Q_OBJECT
 public:
        ScheduledList(QWidget *parent = 0);

 signals:
        void newScheduledSelected();
        void scheduledDetailsSelected(QModelIndex index);
};
#endif
